@@ -197,7 +197,7 @@ class Feature_Evalution:
     
     def feature_importance(self,methods):
         result = pd.DataFrame()
-        result['feature'] = self.data.drop(exclude_cols,axis=1).columns.values.tolist()
+        result['feature'] = self.data.drop(self.exclude_cols,axis=1).columns.values.tolist()
         result['rank_sum'] = 0
         if 'iv' in methods:        
             result['IV'] = self.IV()
